@@ -1,5 +1,5 @@
 .First.lib <- function(lib, pkg) {
    library.dynam("CPE", pkg, lib)
-   cat("CPE 1.4 loaded\n")
+   cat("CPE 1.4.1 loaded\n")
 }
 
